document.addEventListener('DOMContentLoaded', () => {
  const form = document.getElementById('ingredient-form');
  const ingredientsList = document.getElementById('ingredients-list');
  const totalCostElement = document.getElementById('total-cost');
  const servingsInput = document.getElementById('servings');
  const costPerServingElement = document.getElementById('cost-per-serving');
  
  let ingredients = [];

  form.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const name = document.getElementById('ingredient-name').value;
    const cost = parseFloat(document.getElementById('ingredient-cost').value);
    const quantity = parseFloat(document.getElementById('ingredient-quantity').value);
    const unit = document.getElementById('ingredient-unit').value;

    const ingredient = {
      name,
      cost,
      quantity,
      unit,
      totalCost: cost * quantity
    };

    ingredients.push(ingredient);
    updateTable();
    calculateTotals();
    form.reset();
  });

  servingsInput.addEventListener('input', calculateTotals);

  function updateTable() {
    ingredientsList.innerHTML = '';
    
    ingredients.forEach((ingredient, index) => {
      const row = document.createElement('tr');
      row.innerHTML = `
        <td>${ingredient.name}</td>
        <td>${ingredient.quantity} ${ingredient.unit}</td>
        <td>$${ingredient.cost.toFixed(2)}</td>
        <td>$${ingredient.totalCost.toFixed(2)}</td>
        <td>
          <button class="delete-btn" data-index="${index}">Delete</button>
        </td>
      `;
      ingredientsList.appendChild(row);
    });

    // Add delete button listeners
    document.querySelectorAll('.delete-btn').forEach(button => {
      button.addEventListener('click', (e) => {
        const index = parseInt(e.target.dataset.index);
        ingredients.splice(index, 1);
        updateTable();
        calculateTotals();
      });
    });
  }

  function calculateTotals() {
    const totalCost = ingredients.reduce((sum, ingredient) => sum + ingredient.totalCost, 0);
    const servings = parseInt(servingsInput.value) || 1;
    const costPerServing = totalCost / servings;

    totalCostElement.textContent = `$${totalCost.toFixed(2)}`;
    costPerServingElement.textContent = `$${costPerServing.toFixed(2)}`;
  }
});
